{% extends "base.html" %}
{% block content %}
<h1>{{ section.title }}</h1>
{{ section.content | safe }}
<nav>
<ol>
{% for page in section.pages %}
    <li><a href="{{ page.permalink }}">{{ page.title }}</a></li>
{% endfor %}
</ol>
</nav>
{% endblock %}
