<!DOCTYPE html>
<html lang="{{ config.default_language }}">
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>{% block title %}{{ config.title }}{% endblock %}</title>
</head>
<body>
    <nav>
        <a href="{{ config.base_url }}/">{{ config.title }}</a>
        <span style="margin-left: 1rem;">
            <a href="{{ config.base_url }}/guide/">Guide</a>
        </span>
    </nav>
    <main>{% block content %}{% endblock %}</main>
    <footer>
        <p>Built with <a href="https://zorto.dev">Zorto</a></p>
    </footer>
</body>
</html>
